from django.contrib import admin
from .models import Artist, Album, Song

# Register your models here.

# Admin page for Artist model
class ArtistAdmin(admin.ModelAdmin):
    model = Artist

    # list artist name, birth name, monthly listeners
    list_display = ("artist_name", "birth_name", "monthly_listeners")

    # search and filter by artist name, birth name
    search_fields = ("artist_name", "birth_name")
    list_filter = ("artist_name", "birth_name")

# Admin page for Album model
class AlbumAdmin(admin.ModelAdmin):
    model = Album

    # list artist name, birth name, monthly listeners
    list_display = ("album_name", "description", "release_date", "label", "song_count")

    # search by album name, description or label
    search_fields = ("album_name", "description", "label")

    # filter by album name
    list_filter = ("album_name",)

# Admin page for Artist model
class SongAdmin(admin.ModelAdmin):
    model = Song

    # list song title, song length, lyrics, whether or not it has music video
    list_display = ("song_title", "song_length", "lyrics", "music_video")

    # search by song title, lyrics
    search_fields = ("song_title", "lyrics")

    # filter by song title
    list_filter = ("song_title",)


admin.site.register(Artist, ArtistAdmin)
admin.site.register(Album, AlbumAdmin)
admin.site.register(Song, SongAdmin)